<?php
/*
 * Plugin Name: Latest Custom Post Type Updates
 * Plugin URI: http://technicalmastermind.com/wordpress-plugins/latest-custom-post-type-updates/
 * Description: This simple plugin adds a widget that allows for the display of recent posts in any custom post type. It functions almost identically to the built-in WordPress "Recent Posts" widget with the added option of letting you choose which post type it pulls from. Just add the "Latest Custom Post Type" widget to a widget area, give it a title, how many posts to show and what post type you want it to pull from. It's that easy!
 * Version: 1.1
 * Author: David Wood
 * Author URI: http://iamdavidwood.com/
 * License: GPL2
 */

if(!class_exists('tm_latest_cp_widget') && class_exists('WP_Widget')):
class tm_latest_cp_widget extends WP_Widget {
    function tm_latest_cp_widget() { // creates the widget
        $name = __('Latest Custom Post Type'); // The widget name as users will see it
        $description = __('Simple display of the latest updates to your custom post type.'); // The widget description as users will see it

        $this->WP_Widget($id_base = false,
            $name,
            $widget_options = array('classname' => strtolower(get_class($this)), 'description' => $description),
            $control_options = array());
    }

    function form($instance) { // outputs the options form on admin
        // include options form
        include(dirname(__FILE__).'/options.php');
    }

    function update($new_instance, $old_instance) {
        // processes widget options to be saved
        $instance = $old_instance;

        $instance['title'] = strip_tags($new_instance['title']);
        if(!empty($new_instance['numberposts']) && is_numeric($new_instance['numberposts'])) $instance['numberposts'] = (int) strip_tags($new_instance['numberposts']);
        else $instance['numberposts'] = 5;
        $instance['post_type'] = strip_tags($new_instance['post_type']);

        return $instance;
    }

    function widget($args, $instance) {
        $before_title = $before_widget = $after_widget = $after_title = '';
        extract($args, EXTR_IF_EXISTS);
        // Begin widget display
        echo $before_widget;
        echo $before_title.$instance['title'].$after_title;
        echo '<ul class="tm-latest-updates">';

        // Make call to get most recent posts from the specified post type
        $params = array(
            'numberposts' => $instance['numberposts'],
            'orderby' => 'date',
            'order' => 'DESC',
            'post_type' => $instance['post_type'],
        );
        $posts = get_posts($params);
        // Print 'em out!
        if($posts)
            foreach($posts as $post)
                echo '<li><a href="'.get_permalink($post->ID).'" title="'.$post->post_title.'">'.$post->post_title.'</a></li>';
        // Finish widget display
        echo '</ul>'.$after_widget;
    }
}
// register widget
add_action('widgets_init', create_function('', 'return register_widget("tm_latest_cp_widget");'));
endif;
